@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Side-effect Command Module."""
+from __future__ import annotations
 
 import logging
 
@@ -25,54 +26,18 @@ import click
 
 from molecule.command import base
 
+
 LOG = logging.getLogger(__name__)
 
 
 class SideEffect(base.Base):
-    """
-    This action has side effects and not enabled by default.
+    """This action has side effects and not enabled by default.
 
     See the provisioners documentation for further details.
-
-    .. program:: molecule side-effect
-
-    .. option:: molecule side-effect
-
-        Target the default scenario.
-
-    .. program:: molecule side-effect --scenario-name foo
-
-    .. option:: molecule side-effect --scenario-name foo
-
-        Targeting a specific scenario.
-
-    .. program:: molecule --debug side-effect
-
-    .. option:: molecule --debug side-effect
-
-        Executing with `debug`.
-
-    .. program:: molecule --base-config base.yml side-effect
-
-    .. option:: molecule --base-config base.yml side-effect
-
-        Executing with a `base-config`.
-
-    .. program:: molecule --env-file foo.yml side-effect
-
-    .. option:: molecule --env-file foo.yml side-effect
-
-        Load an env file to read variables from when rendering
-        molecule.yml.
     """
 
-    def execute(self, action_args=None):
-        """
-        Execute the actions necessary to perform a `molecule side-effect` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
+        """Execute the actions necessary to perform a `molecule side-effect` and returns None."""
         if not self._config.provisioner.playbooks.side_effect:
             msg = "Skipping, side effect playbook not configured."
             LOG.warning(msg)
@@ -89,10 +54,10 @@ class SideEffect(base.Base):
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
     help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
-def side_effect(ctx, scenario_name):  # pragma: no cover
+def side_effect(ctx, scenario_name):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
     """Use the provisioner to perform side-effects to the instances."""
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {"subcommand": subcommand}
 
     base.execute_cmdline_scenarios(scenario_name, args, command_args)
